@@ -228,10 +228,8 @@ class CodeEditor(QTextEdit):
             cur.movePosition(QTextCursor.Up)
             cur.movePosition(QTextCursor.EndOfLine)
             cur.insertText(line)
-            cur.setPosition(end)
+            cur.setPosition(end + len(line))
             cur.movePosition(QTextCursor.Down)
-            cur.movePosition(QTextCursor.EndOfLine)
-            cur.movePosition(QTextCursor.Right)
             cur.movePosition(QTextCursor.EndOfLine, QTextCursor.KeepAnchor)
             cur.movePosition(QTextCursor.Right, QTextCursor.KeepAnchor)
             cur.removeSelectedText()
